#!/usr/bin/env bash
# ENV
docker_login="customercomplitech"
docker_pass="softCopy2"
docker_network_name="deepstream_docker_net"
docker_env_file="./docker.env"
core_env_file="./core.env"
docker_compose_file="docker-compose.yml"
core_compose_file="core-compose.yml"
UPD_FILE="update.sql"
db_container_name="fnv_db"
wget_url="http://download.faceneurovision.com/fnv5/x86/docker"


docker login --username=$docker_login --password=$docker_pass


pull_docker_images(){
echo -e "\033[33m### Pull docker images ###\033[0m"
wget -q --show-progress $wget_url/$docker_env_file -O $docker_env_file
for docker_image in `cat $docker_env_file | grep _IMAGE= | cut -d "=" -f 2`
do
  docker pull $docker_image
done
}


pull_core_images(){
echo -e "\033[33m### Pull core images ###\033[0m"
wget -q --show-progress $wget_url/$core_env_file -O $core_env_file
for docker_image in `cat $core_env_file | grep _IMAGE= | cut -d "=" -f 2`
do
  docker pull $docker_image
done
}


update_docker_compose_file(){
echo -e "\033[33m### Update docker-compose.yml ###\033[0m"
wget -q --show-progress $wget_url/$docker_compose_file -O $docker_compose_file
docker-compose -f /home/$USER/FNV/docker/docker-compose.yml down 2>/dev/null
mkdir -p /home/$USER/FNV/docker
cat $docker_compose_file > /home/$USER/FNV/docker/docker-compose.yml
cat $docker_env_file > /home/$USER/FNV/docker/.env
docker-compose -f /home/$USER/FNV/docker/docker-compose.yml up -d
}


update_core_compose_file(){
echo -e "\033[33m### Update core docker-compose.yml ###\033[0m"
wget -q --show-progress $wget_url/$core_compose_file -O $core_compose_file
docker ps -a | grep "fnv_camera" | awk  '{print $1}' | xargs docker rm -f || echo "containers with cameras are not running"
docker-compose -f /home/$USER/FNV/core/docker-compose.yml down 2>/dev/null
mkdir -p /home/$USER/FNV/core
cat $core_compose_file > /home/$USER/FNV/core/docker-compose.yml
cat $core_env_file > /home/$USER/FNV/core/.env
docker-compose -f /home/$USER/FNV/core/docker-compose.yml up -d
}


update_data_base(){
echo -e "\033[33m### Update Postgre DB ###\033[0m"
wget -q --show-progress $wget_url/$UPD_FILE -O $UPD_FILE
DB_CONT=`docker ps -aqf "name=$db_container_name"`
for id in $DB_CONT; do
        echo "Update for container $id is in progress..."
        docker exec $id mkdir -p /updatedb
        docker cp $UPD_FILE $id:/updatedb
        docker exec $id psql -U postgres -h 127.0.0.1 -p 5432 -d sentinel -f /updatedb/$UPD_FILE;
        echo "The update for $id was applied."
done
}


wait_postgres_start() {
  echo "Waiting for Postgres..."
  attempts=0
  while ! docker exec $db_container_name pg_isready -U postgres >/dev/null 2>&1; do
    echo "Postgres is not available yet, sleeping for 5 seconds..."
    sleep 5
    attempts=$((attempts + 1))
    if [ $attempts -eq 20 ]; then
      echo "Postgres did not start after 20 attempts. Exiting..."
      exit 1
    fi
  done
  echo "Postgres is now running."
}


create_docker_network() {
echo -e "\033[33m### Creation docker network with fix subnet ###\033[0m"
docker network inspect $docker_network_name --format='{{range $container, $config := .Containers}}{{println (index $config "Name")}}{{end}}' 2>/dev/null | xargs -n1 docker network disconnect $docker_network_name 2>/dev/null
docker network rm $docker_network_name 2>/dev/null || echo "network $docker_network_name not found"
docker network create --subnet 172.48.0.0/16 $docker_network_name && echo "network $docker_network_name subnet 172.48.0.0/16 created" || echo "network $docker_network_name not created"
}


create_docker_network
pull_core_images
update_core_compose_file
pull_docker_images
update_docker_compose_file
docker ps
wait_postgres_start
update_data_base
docker restart fnv_server

echo -e "\033[33m### FINISH ###\033[0m"
