#!/usr/bin/env bash

#ENV
PKGS="nano mc curl htop openssh-server"
DCKRDEP="apt-transport-https ca-certificates gnupg-agent software-properties-common"
DCKRLINK="https://download.docker.com/linux/ubuntu/gpg"
DCKRREP="deb [arch=amd64] https://download.docker.com/linux/ubuntu $(lsb_release -cs) stable"
DCKRVER="5:23.0.5-1~ubuntu.20.04~focal"
DCKRPKGS="docker-ce=$DCKRVER docker-ce-cli=$DCKRVER containerd.io"
DCLINK="https://github.com/docker/compose/releases/download/1.29.2/docker-compose-$(uname -s)-$(uname -m)"
DCOUT="/usr/local/bin/docker-compose"
NVDKEY="https://nvidia.github.io/nvidia-docker/gpgkey"
DISTRIBUTION=$(. /etc/os-release; echo $ID$VERSION_ID)
NVD="https://nvidia.github.io/nvidia-docker/$DISTRIBUTION/nvidia-docker.list"


pass_check() {
sudo -k; read -s -p "Please enter the password for sudo: " PW
if sudo -lS &>/dev/null << EOF
$PW
EOF
then
  echo ""
  echo -e "\033[32mPassword correct\033[0m"
else
  echo -e "\033[31mPassword incorrect\033[0m"
  pass_check
fi
}
pass_check

SP="echo $PW"
SS="sudo -S"


# Start
echo ""
echo  -e "\033[33m### Step 1 - Preinstall ###\033[0m"
$SP | $SS apt update -y
$SP | $SS apt install -y $PKGS

echo  -e "\033[33m### Step 2 - Docker install ###\033[0m"
# Docker dependencies
$SP | $SS apt install -y $DCKRDEP
# Docker key
$SP | $SS curl -fsSL $DCKRLINK | sudo apt-key add -
# Docker repository
$SP | $SS add-apt-repository "$DCKRREP"
# Docker install
$SP | $SS apt update -y
$SP | $SS apt install -y $DCKRPKGS
$SP | $SS usermod -aG docker $USER
# Chmod for docker dir
$SP | $SS curl -L $DCLINK -o $DCOUT
$SP | $SS chmod +x $DCOUT
$SP | $SS chmod ug+s /usr/bin/docker
$SP | $SS chmod ug+s $DCOUT

echo  -e "\033[33m### Step 3 Nvidia-docker install ###\033[0m"
$SP | $SS curl -s -L $NVDKEY | sudo apt-key add -
$SP | $SS curl -s -L $NVD | sudo tee /etc/apt/sources.list.d/nvidia-docker.list
$SP | $SS apt update -y
$SP | $SS apt install -y nvidia-docker2

echo  -e "\033[33m### Step 4 configuring environment ###\033[0m"
$SP | $SS mkdir /etc/systemd/system/docker.service.d
$SP | $SS echo -e "[Service]\nExecStart=\nExecStart=/usr/bin/dockerd -H fd:// -H tcp://0.0.0.0:2375" > docker_override.conf
$SP | $SS mv docker_override.conf /etc/systemd/system/docker.service.d/.
$SP | $SS chown root:root /etc/systemd/system/docker.service.d/docker_override.conf
$SP | $SS systemctl daemon-reload
$SP | $SS systemctl restart docker.service

$SP | $SS nvidia-ctk runtime configure --runtime=docker

echo -e "\033[33m### Step 6 Reboot server###\033[0m"
sleep 10
$SP | $SS reboot now
